<?php        

defined('C5_EXECUTE') or die(_("Access Denied."));

class SkybluesofaSocialSharePackage extends Package {

	protected $pkgHandle = 'skybluesofa_social_share';
	protected $appVersionRequired = '5.4';
	protected $pkgVersion = '5.6.0.0.5.2';
	public function getPackageName() {
		return t("Socializer");
	}
	
	public function getPackageDescription() {
		return t("Add social networking capabilities to your site.");
    }
	
    public function on_start() {
	if (version_compare(APP_VERSION,'5.5.0', '>=')) {
	    if (!$this->hasMultipleCIDs() && !$this->isInternalPage()) {
    		$this->add_events();
    		$this->add_interface_bar_buttons();
	    }
    	}
    }
    
    private function hasMultipleCIDs() {
	$hasMultipleCIDs = false;
	if (is_array($_GET['cID'])) {
	    $hasMultipleCIDs = true;
	}
	return $hasMultipleCIDs;
    }
    private function isInternalPage() {
	$isInternalPage = false;
	$page = false;
	$path = $_SERVER['PATH_INFO'];
	$path = explode('/', $path);
	if (count($path)) {
	    $page = array_pop($path);
	    $page = strtolower($page);
	}
	if ($page) {
	    $internalPages = array(
		'edit_collection_popup.php','sitemap_update.php','versions.php','sitemap_check_in','edit_block_popup'
	    );
	    if (in_array($page, $internalPages)) {
		$isInternalPage = true;
	    }
	}
	return $isInternalPage;
    }
	
    public function install() {
		$pkg = parent::install();
		$this->installBlocks($pkg);
		$this->installDashboard($pkg);
		$this->installTableData();
		$this->updateSocialShareTooltips();
	}
	
	public function upgrade() {
		parent::upgrade();
		$pkg = $this->getByID($this->getPackageID());
		$this->installBlocks($pkg);
		$this->installDashboard($pkg);
		$this->installTableData();
		$this->updateSocialShareTooltips();
	}
	
	private function installBlocks($pkg) {
		if (!BlockType::getByHandle('skybluesofa_social_connect')) {
			BlockType::installBlockTypeFromPackage('skybluesofa_social_connect', $pkg);
		}
		if (!BlockType::getByHandle('skybluesofa_social_share')) {
			BlockType::installBlockTypeFromPackage('skybluesofa_social_share', $pkg);
		}
		if (!BlockType::getByHandle('skybluesofa_css_share')) {
			BlockType::installBlockTypeFromPackage('skybluesofa_css_share', $pkg);
		}
		/*
		if (!BlockType::getByHandle('skybluesofa_social_widget')) {
			BlockType::installBlockTypeFromPackage('skybluesofa_social_widget', $pkg);
		}*/
	}
	
    private function installDashboard($pkg) {
		Loader::model('single_page');
		$db = Loader::db();
		
		$dashPages = array(
			array('pkg'=>null,'path'=>'/dashboard/skybluesofa','name'=>'Sky Blue Sofa Web Design','description'=>'Make your site a better place.')
			,array('pkg'=>$pkg,'path'=>'/dashboard/skybluesofa/social_connect','name'=>'Social Connect','description'=>'Add and update networks for the Social Connect block')
			,array('pkg'=>$pkg,'path'=>'/dashboard/skybluesofa/social_post','name'=>'Social Promotion','description'=>'Post page additions and updates to Social Media')
		);
		//Remove old 'social_share' page. We'll replace it with 'social_connect'
		$dp = Page::getByPath('/dashboard/skybluesofa/social_share');
		$dp->delete();
		
		foreach ($dashPages as $dashPage) {
			$dp = Page::getByPath($dashPage['path']);
			if($dp->cID==0) {
				$sp = SinglePage::add($dashPage['path'],$dashPage['pkg']);
				$sp->update(array('cName'=>t($dashPage['name']), 'cDescription'=>t($dashPage['description'])));
				$db->query("UPDATE Pages SET cFilename=? WHERE cID = ?", array($dashPage['path'].'.php',$sp->cID));
			}
		}
    }
	
	private function installTableData() {
		$this->installSocialShareTableData();
		$this->installSocialPostTableData();
		$this->cleanupSharedEmails();
	}
	
    private function installSocialShareTableData() {
		$db = Loader::db();
		$rows = array(
			array('name'=>'about.me','handle'=>'aboutdotme','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'AIM','handle'=>'aim','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Amazon','handle'=>'amazon','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'BBC ID','handle'=>'bbcid','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Bebo','handle'=>'bebo','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Concrete5','handle'=>'concrete5','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Creative Commons','handle'=>'creativecommons','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Dailymile','handle'=>'dailymile','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Delicious','handle'=>'delicious','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Digg','handle'=>'digg','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>1,'css_share'=>1)
			,array('name'=>'Dopplr','handle'=>'dopplr','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Dribbble','handle'=>'dribbble','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'eBay','handle'=>'ebay','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'E-mail','handle'=>'email','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>1,'css_share'=>1)
			,array('name'=>'Facebook','handle'=>'facebook','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>1,'css_share'=>1)
			,array('name'=>'Feed','handle'=>'feed','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'FFFFound','handle'=>'ffffound','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Fire Eagle','handle'=>'fireeagle','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Fitocracy','handle'=>'fitocracy','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Flickr','handle'=>'flickr','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'FormSpring','handle'=>'formspring','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Forrst','handle'=>'forrst','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Foursquare','handle'=>'foursquare','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'GeoTag','handle'=>'geotag','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Get Satisfaction','handle'=>'getsatisfaction','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Github','handle'=>'github','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'GoodReads','handle'=>'goodreads','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Google','handle'=>'google','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Google+','handle'=>'google+','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>1,'css_share'=>1)
			,array('name'=>'Google Talk','handle'=>'google-talk','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Gowalla','handle'=>'gowalla','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'HuffDuffer','handle'=>'huffduffer','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Hyves','handle'=>'hyves','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>1,'css_share'=>1)
			,array('name'=>'Identi.ca','handle'=>'identica','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'iLike','handle'=>'ilike','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'IMDb','handle'=>'imdb','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'iTunes','handle'=>'itunes','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Lanyrd','handle'=>'lanyrd','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Last.fm','handle'=>'lastfm','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'LinkedIn','handle'=>'linkedin','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>1,'css_share'=>1)
			,array('name'=>'Meetup','handle'=>'meetup','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Messenger','handle'=>'messenger','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Mixx','handle'=>'mixx','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'MySpace','handle'=>'myspace','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'NetVibes','handle'=>'netvibes','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'NewsVine','handle'=>'newsvine','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Nike+','handle'=>'nikeplus','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'OpenID','handle'=>'openid','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Orkut','handle'=>'orkut','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'PayPal','handle'=>'paypal','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Picasa','handle'=>'picasa','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'PinBoard','handle'=>'pinboard','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Pinterest','handle'=>'pinterest','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>1,'css_share'=>1)
			,array('name'=>'Plancast','handle'=>'plancast','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Posterous','handle'=>'posterous','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Rdio','handle'=>'rdio','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Readernaut','handle'=>'readernaut','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Reddit','handle'=>'reddit','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>1,'css_share'=>1)
			,array('name'=>'Runkeeper','handle'=>'runkeeper','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Share','handle'=>'share','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Skype','handle'=>'skype','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'SlideShare','handle'=>'slideshare','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Speaker Deck','handle'=>'speakerdeck','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Spotify','handle'=>'spotify','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'StumbleUpon','handle'=>'stumbleupon','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>1,'css_share'=>1)
			,array('name'=>'Tumblr','handle'=>'tumblr','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Twitter','handle'=>'twitter','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>1,'css_share'=>1)
			,array('name'=>'Upcoming','handle'=>'upcoming','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'vCard','handle'=>'vcard','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Viddler','handle'=>'viddler','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Vimeo','handle'=>'vimeo','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Website','handle'=>'website','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Wikipedia','handle'=>'wikipedia','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'xBox Live','handle'=>'xbox','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Xing','handle'=>'xing','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Yahoo!','handle'=>'yahoo','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Yahoo! Messenger','handle'=>'yahoo-messenger','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Yelp','handle'=>'yelp','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'YouTube','handle'=>'youtube','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
			,array('name'=>'Zootool','handle'=>'zootool','active'=>1,'show_existing'=>1,'packaged'=>1,'connect'=>1,'share'=>0,'css_share'=>0)
		);
		foreach ($rows as $row) {
			$q = $db->GetOne("SELECT * FROM btSkybluesofaSocialNetworks WHERE handle='".$row['handle']."'");
			if (!isset($q['value'])) {
				$db->Execute("INSERT INTO btSkybluesofaSocialNetworks (".implode(', ',array_keys($row)).") VALUES ('".implode("', '", array_values($row))."')");
			} else {
				$db->Execute("UPDATE btSkybluesofaSocialNetworks SET css_share=? WHERE handle=?", array($row['css_share'], $row['handle']));
			}
		}
	}

    private function installSocialPostTableData() {
		$db = Loader::db();
		$rows = array(
			array('group_name'=>'twitter','handle'=>'use','title'=>'Use Network','value'=>'0')
			,array('group_name'=>'twitter','handle'=>'oauth_token','title'=>'Twitter OAuth Token','value'=>'')
			,array('group_name'=>'twitter','handle'=>'oauth_token_secret','title'=>'Twitter OAuth Token Secret','value'=>'')
			,array('group_name'=>'twitter','handle'=>'connected','title'=>'Connected to Network','value'=>'0')
			,array('group_name'=>'twitter','handle'=>'prefix','title'=>'Prefix','value'=>'{"0":"New Article - "}')
			,array('group_name'=>'twitter','handle'=>'use_hashtags','title'=>'Use Hashtags','value'=>'1')
			,array('group_name'=>'twitter','handle'=>'send_post','title'=>'Send Post','value'=>'1')
			,array('group_name'=>'twitter','handle'=>'allow_promotion','title'=>'Allow Page Promotion','value'=>'1')
			,array('group_name'=>'twitter','handle'=>'promote_default','title'=>'Promote by Default','value'=>'1')
			,array('group_name'=>'twitter','handle'=>'promote_prefix','title'=>'Promote Prefix','value'=>'Check out this great article - ')
			,array('group_name'=>'twitter','handle'=>'use_hashtags_promote_default','title'=>'Use Hashtags','value'=>'1')
			
			,array('group_name'=>'facebook','handle'=>'app_id','title'=>'Facebook AppID','value'=>'')
			,array('group_name'=>'facebook','handle'=>'app_secret','title'=>'Facebook App Secret','value'=>'')
			,array('group_name'=>'facebook','handle'=>'use','title'=>'Use Network','value'=>'0')
			,array('group_name'=>'facebook','handle'=>'oauth_token','title'=>'Facebook OAuth Token','value'=>'')
			,array('group_name'=>'facebook','handle'=>'post_to_page','title'=>'The page stream that you would like to post on','value'=>'')
			,array('group_name'=>'facebook','handle'=>'post_to_page_name','title'=>'The name of the page stream that you would like to post on','value'=>'')
			,array('group_name'=>'facebook','handle'=>'prefix','title'=>'Prefix','value'=>'New Article')
			,array('group_name'=>'facebook','handle'=>'use_hashtags','title'=>'Use Hashtags','value'=>'1')
			,array('group_name'=>'facebook','handle'=>'send_post','title'=>'Send Post','value'=>'1')
			,array('group_name'=>'facebook','handle'=>'allow_promotion','title'=>'Allow Page Promotion','value'=>'1')
			,array('group_name'=>'facebook','handle'=>'promote_default','title'=>'Promote by Default','value'=>'1')
			,array('group_name'=>'facebook','handle'=>'promote_prefix','title'=>'Promote Prefix','value'=>'Check out this great article - ')
			,array('group_name'=>'facebook','handle'=>'use_hashtags_promote_default','title'=>'Use Hashtags','value'=>'1')

			,array('group_name'=>'linkedin','handle'=>'api_key','title'=>'LinkedIn AppID','value'=>'')
			,array('group_name'=>'linkedin','handle'=>'api_secret','title'=>'LinkedIn App Secret','value'=>'')
			,array('group_name'=>'linkedin','handle'=>'use','title'=>'Use Network','value'=>'0')
			,array('group_name'=>'linkedin','handle'=>'oauth_token','title'=>'OAuth User Token','value'=>'')
			,array('group_name'=>'linkedin','handle'=>'oauth_secret','title'=>'OAuth User Secret','value'=>'')
			,array('group_name'=>'linkedin','handle'=>'access_token','title'=>'Access Token','value'=>'')
			,array('group_name'=>'linkedin','handle'=>'connected','title'=>'Connected to Network','value'=>'0')
			,array('group_name'=>'linkedin','handle'=>'prefix','title'=>'Prefix','value'=>'New Article')
			,array('group_name'=>'linkedin','handle'=>'send_post','title'=>'Send Post','value'=>'1')
			,array('group_name'=>'linkedin','handle'=>'allow_promotion','title'=>'Allow Page Promotion','value'=>'1')
			,array('group_name'=>'linkedin','handle'=>'promote_default','title'=>'Promote by Default','value'=>'1')
			,array('group_name'=>'linkedin','handle'=>'promote_prefix','title'=>'Promote Prefix','value'=>'Check out this great article - ')
		);
		foreach ($rows as $row) {
			$handle = $db->GetOne("SELECT handle FROM btSkybluesofaSocialPostSettings WHERE group_name='".$row['group_name']."' AND handle='".$row['handle']."'");
			if (!$handle) {
				$db->Execute("INSERT INTO btSkybluesofaSocialPostSettings (".implode(', ',array_keys($row)).") VALUES ('".implode("', '", array_values($row))."')");
			}
		}
	}
	
	private function cleanupSharedEmails() {
		$db = Loader::db();
		$db->execute("DELETE FROM btSkybluesofaSharedEmails WHERE (toName IS NULL OR toName='') OR (fromName IS NULL OR fromName='')");
		$db->execute("DELETE FROM btSkybluesofaSharedEmails WHERE toName NOT LIKE '%@%.%' OR fromName NOT LIKE '%@%.%'");
	}
	
	private function updateSocialShareTooltips() {
		$db = Loader::db();
		$rows = $db->GetArray("SELECT * FROM btSkybluesofaSocialNetworks WHERE tooltip IS NULL");
		foreach ($rows as $row) {
			$defaultTooltip = 'Connect with me on '.$row['name'];
			if ($row['handle']=='email') {
				$defaultTooltip = 'Connect with me via Email';
			} elseif ($row['handle']=='feed') {
				$defaultTooltip = 'Subscribe to my feed';
			}
			$db->Execute("UPDATE btSkybluesofaSocialNetworks SET tooltip=? WHERE id=?", array($defaultTooltip, $row['id']));
		}
	}

    private function add_events() {
    	Events::extend('on_composer_publish', 'SocialPost', 'post_on_publish', 'packages/skybluesofa_social_share/models/social_post.php');
    }
    
    private function add_interface_bar_buttons() {
   		$req = Request::get();
   		if ($req->getRequestCollectionPath() != '') {
   			if (ENABLE_LEGACY_CONTROLLER_URLS) {
   				$c = Page::getByPath($req->getRequestCollectionPath(), false);
   			} else {
   				$c = $req->getRequestedPage();
   			}
   		} else {
	   		$requestCollectionID = $req->getRequestCollectionID();
			if (is_array($requestCollectionID)) {
				$requestCollectionID = HOME_CID;
			}
			$c = Page::getByID($requestCollectionID, false);
   			
   		}
   		$cID = (!$c->isError()) ? $c->cID : '';
		$ihm = Loader::helper('concrete/interface/menu');
		$uh = Loader::helper('concrete/urls');
		$ihm->addPageHeaderMenuItem(
			'social_share_promote_page', 
			'Promote Page<br><span style="font-weight:normal;font-size:75%;opacity:.75;">via Social Media</span>', 
			'right', 
			array(
				'dialog-title' => t('Promote Page via Social Media')
				,'href' => $uh->getToolsUrl('promote_page', 'skybluesofa_social_share')
				,'dialog-on-open' => "$(\'#ccm-page-edit-nav-social_share_promote_page\').removeClass(\'ccm-nav-loading\');$(\'#skybluesofa_promote_page_cID\').val(\'".$cID."\');"
				,'dialog-width' => '500'
				,'dialog-height' => "400"
				,'dialog-modal' => "false"
				,'class' => 'dialog-launch'
			), 
			'skybluesofa_social_share'
		);
    }
}
